@@ -41,10 +41,18 @@ fn get_metadata(playable: Option<Playable>, spotify: Spotify) -> Metadata {
     // Fetch full track details in case this playable is based on a SimplifiedTrack
     // This is necessary because SimplifiedTrack objects don't contain a cover_url
     let playable_full = playable.and_then(|p| match p {
-        Playable::Track(track) => spotify
-            .track(&track.id.unwrap_or_default())
-            .as_ref()
-            .map(|t| Playable::Track(t.into())),
+        Playable::Track(track) => {
+            if track.cover_url.is_some() {
+                // We already have `cover_url`, no need to fetch the full track
+                Some(Playable::Track(track))
+            } else {
+                spotify
+                    .api
+                    .track(&track.id.unwrap_or_default())
+                    .as_ref()
+                    .map(|t| Playable::Track(t.into()))
+            }
+        }
         Playable::Episode(episode) => Some(Playable::Episode(episode)),
     });
     let playable = playable_full.as_ref();
@@ -551,7 +559,7 @@ fn run_dbus_server(
             let uri_type = UriType::from_uri(&uri);
             match uri_type {
                 Some(UriType::Album) => {
-                    if let Some(a) = spotify.album(&id) {
+                    if let Some(a) = spotify.api.album(id) {
                         if let Some(t) = &Album::from(&a).tracks {
                             queue.clear();
                             let index = queue.append_next(
@@ -564,14 +572,14 @@ fn run_dbus_server(
                     }
                 }
                 Some(UriType::Track) => {
-                    if let Some(t) = spotify.track(&id) {
+                    if let Some(t) = spotify.api.track(id) {
                         queue.clear();
                         queue.append(Playable::Track(Track::from(&t)));
                         queue.play(0, false, false)
                     }
                 }
                 Some(UriType::Playlist) => {
-                    if let Some(p) = spotify.playlist(&id) {
+                    if let Some(p) = spotify.api.playlist(id) {
                         let mut playlist = Playlist::from(&p);
                         let spotify = spotify.clone();
                         playlist.load_tracks(spotify);
@@ -587,7 +595,7 @@ fn run_dbus_server(
                     }
                 }
                 Some(UriType::Show) => {
-                    if let Some(s) = spotify.get_show(&id) {
+                    if let Some(s) = spotify.api.get_show(id) {
                         let mut show: Show = (&s).into();
                         let spotify = spotify.clone();
                         show.load_all_episodes(spotify);
@@ -605,14 +613,14 @@ fn run_dbus_server(
                     }
                 }
                 Some(UriType::Episode) => {
-                    if let Some(e) = spotify.episode(&id) {
+                    if let Some(e) = spotify.api.episode(id) {
                         queue.clear();
                         queue.append(Playable::Episode(Episode::from(&e)));
                         queue.play(0, false, false)
                     }
                 }
                 Some(UriType::Artist) => {
-                    if let Some(a) = spotify.artist_top_tracks(&id) {
+                    if let Some(a) = spotify.api.artist_top_tracks(id) {
                         queue.clear();
                         queue.append_next(a.iter().map(|track| Playable::Track(track.clone())).collect());
                         queue.play(0, false, false)
